@@ -21,9 +21,9 @@ The library to install is dependent on your operating system:
  - OSX: install MacFSEvents
 
 """
-from metadata import *
-from scanner import Scanner
-from runner import Sniffer
-from main import main, run
+from .metadata import *
+from .scanner import Scanner
+from .runner import Sniffer
+from .main import main, run
 
 __all__ = ['Scanner', 'Sniffer', 'main', 'run']
