@@ -6,7 +6,8 @@ It provides a polling technique which is an OS-independent and uses no third-par
 libraries at the cost of performance. The polling technique constantly walks through
 the directory tree to see which files changed, calling os.stat on the files.
 """
-from base import PollingScanner
+from __future__ import absolute_import
+from .base import PollingScanner
 
 __all__ = ['Scanner']
 
@@ -17,9 +18,10 @@ Scanner = PollingScanner
 # Plus, factories remind me a lot of java...
 def _import(module, cls):
     global Scanner
+
     try:
         cls = str(cls)
-        mod = __import__(str(module), globals(), locals(), [cls], -1)
+        mod = __import__(str(module), globals(), locals(), [cls], 1)
         Scanner = getattr(mod, cls)
     except ImportError:
         pass
